@@ -1,3 +1,9 @@
+"""
+$description America-based television network centred towards business and capital market programming.
+$url bloomberg.com
+$type live, vod
+"""
+
 import logging
 import re
 
