@@ -1,3 +1,9 @@
+"""
+$description Global video on-demand hosting platform owned by Comcast.
+$url player.theplatform.com
+$type vod
+"""
+
 import logging
 import re
 
