@@ -1,5 +1,12 @@
+"""
+$description Russian live-streaming and video hosting social platform.
+$url vk.com
+$type live, vod
+"""
+
 import logging
 import re
+from hashlib import md5
 from urllib.parse import parse_qsl, unquote, urlparse
 
 from streamlink.exceptions import NoStreamsError
@@ -7,6 +14,7 @@ from streamlink.plugin import Plugin, PluginError, pluginmatcher
 from streamlink.plugin.api import validate
 from streamlink.stream.dash import DASHStream
 from streamlink.stream.hls import HLSStream
+from streamlink.utils.url import update_qsd
 
 log = logging.getLogger(__name__)
 
@@ -19,6 +27,22 @@ log = logging.getLogger(__name__)
 ))
 class VK(Plugin):
     API_URL = "https://vk.com/al_video.php"
+    HASH_COOKIE = "hash429"
+
+    def _get_cookies(self):
+        def on_response(res, **kwargs):
+            if res.headers.get("x-waf-redirect") == "1":
+                if not res.headers.get("X-WAF-Backend-Status"):
+                    log.debug("Getting WAF cookie")
+                    cookie = res.cookies.get(self.HASH_COOKIE)
+                    key = md5(cookie.encode("utf-8")).hexdigest()
+                    res.headers["Location"] = update_qsd(res.headers["Location"], qsd={"key": key})
+                    return res
+                elif res.headers.get("X-WAF-Backend-Status") == "challenge_success":
+                    self.session.http.cookies.update(res.cookies)
+                    return res
+
+        self.session.http.get("https://vk.com/", hooks={"response": on_response})
 
     def _has_video_id(self):
         return any(m for m in self.matches[:-1])
@@ -50,21 +74,20 @@ class VK(Plugin):
         raise NoStreamsError(self.url)
 
     def _get_streams(self):
+        self._get_cookies()
         self.follow_vk_redirect()
 
         video_id = self.match.group("video_id")
         if not video_id:
             return
 
-        log.debug(f"video ID: {video_id}")
+        log.debug(f"Video ID: {video_id}")
         try:
             data = self.session.http.post(
                 self.API_URL,
-                params={
-                    "act": "show_inline",
-                    "al": "1",
-                    "video": video_id,
-                },
+                params={"act": "show"},
+                data={"act": "show", "al": "1", "video": video_id},
+                headers={"Referer": self.url},
                 schema=validate.Schema(
                     validate.transform(lambda text: re.sub(r"^\s*<!--\s*", "", text)),
                     validate.parse_json(),
