@@ -34,6 +34,19 @@ class TestPluginCanHandleUrlYouTube(PluginCanHandleUrl):
         "https://youtu.be/0123456789A",
     ]
 
+    should_match_groups = [
+        ("https://www.youtube.com/v/aqz-KE-bpKQ", {
+            "video_id": "aqz-KE-bpKQ",
+        }),
+        ("https://www.youtube.com/embed/aqz-KE-bpKQ", {
+            "embed": "embed",
+            "video_id": "aqz-KE-bpKQ",
+        }),
+        ("https://www.youtube.com/watch?v=aqz-KE-bpKQ", {
+            "video_id": "aqz-KE-bpKQ",
+        }),
+    ]
+
     should_not_match = [
         "https://accounts.google.com/",
         "https://www.youtube.com",
@@ -47,18 +60,6 @@ class TestPluginCanHandleUrlYouTube(PluginCanHandleUrl):
     ]
 
 
-@pytest.mark.parametrize("url,group,expected", [
-    ("https://www.youtube.com/v/aqz-KE-bpKQ", "video_id", "aqz-KE-bpKQ"),
-    ("https://www.youtube.com/embed/aqz-KE-bpKQ", "video_id", "aqz-KE-bpKQ"),
-    ("https://www.youtube.com/watch?v=aqz-KE-bpKQ", "video_id", "aqz-KE-bpKQ"),
-])
-def test_match_url(url, group, expected):
-    YouTube.bind(Mock(), "tests.plugins.test_youtube")
-    plugin = YouTube(url)
-    assert plugin.match is not None
-    assert plugin.match.group(group) == expected
-
-
 @pytest.mark.parametrize("url,expected", [
     ("http://gaming.youtube.com/watch?v=0123456789A", "https://www.youtube.com/watch?v=0123456789A"),
     ("http://youtu.be/0123456789A", "https://www.youtube.com/watch?v=0123456789A"),
